@@ -33,8 +33,8 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <math.h>
 #include <getopt.h>
+#include <cmath>
 #include <string>
 #include <locale>
 
@@ -150,7 +150,7 @@ bool parse_max_peak_level(const char *value, double &peak)
 {
     char *rest = nullptr;
     double max_peak = strtod(value, &rest);
-    if (rest == value || !isfinite(max_peak)) {
+    if (rest == value || !std::isfinite(max_peak)) {
         output_error("Invalid max peak level '{}'", value);
         return false;
     }
@@ -182,7 +182,7 @@ static void custom_mode(int argc, char *argv[])
     unsigned int nb_files   = 0;
     opterr = 0;
 
-    const char *short_opts = "+ac:m:tl:O::qps:LSI:o:h?";
+    const char *short_opts = "+ac:m:tdl:O::qps:LSI:o:h?";
     static struct option long_opts[] = {
         { "album",           no_argument,       nullptr, 'a' },
         { "skip-existing",   no_argument,       nullptr, 'S' },
@@ -190,6 +190,7 @@ static void custom_mode(int argc, char *argv[])
         { "clip-mode",       required_argument, nullptr, 'c' },
         { "max-peak",        required_argument, nullptr, 'm' },
         { "true-peak",       no_argument,       nullptr, 't' },
+        { "dual-mono",       no_argument,       nullptr, 'd' },
 
         { "loudness",        required_argument, nullptr, 'l' },
 
@@ -220,7 +221,8 @@ static void custom_mode(int argc, char *argv[])
         .id3v2version = ID3V2_KEEP,
         .opus_mode = 'd',
         .skip_mp4 = false,
-        .preserve_mtimes = false
+        .preserve_mtimes = false,
+        .dual_mono = false
     };
 
     while ((rc = getopt_long(argc, argv, short_opts, long_opts, &i)) != -1) {
@@ -249,6 +251,11 @@ static void custom_mode(int argc, char *argv[])
                 break;
             }
 
+            case 'd': {
+                config.dual_mono = true;
+                break;
+            }
+
             case 'l': {
                 if (!parse_target_loudness(optarg, config.target_loudness))
                     quit(EXIT_FAILURE);
@@ -439,6 +446,7 @@ static inline void help_custom() {
     CMD_HELP("--clip-mode=a", "-c a", "Clipping protection always enabled");
     CMD_HELP("--max-peak=n", "-m n", "Use max peak level n dB for clipping protection");
     CMD_HELP("--true-peak",  "-t", "Use true peak for peak calculations");
+    CMD_HELP("--dual-mono",  "-d", "Treat mono files as dual-mono");
 
     rsgain::print("\n");
 
