@@ -65,8 +65,8 @@
 #include "output.hpp"
 
 #define TAGLIB_VERSION (TAGLIB_MAJOR_VERSION * 10000 + TAGLIB_MINOR_VERSION * 100 + TAGLIB_PATCH_VERSION)
-#define FORMAT_GAIN(gain) format("{:.2f} dB", gain)
-#define FORMAT_PEAK(peak) format("{:.6f}", peak)
+#define FORMAT_GAIN(gain) rsgain::format("{:.2f} dB", gain)
+#define FORMAT_PEAK(peak) rsgain::format("{:.6f}", peak)
 #define OPUS_HEADER_SIZE 47
 #define OGG_ROW_SIZE 4
 #define OPUS_HEAD_OFFSET 7 * OGG_ROW_SIZE
@@ -79,7 +79,6 @@
 
 #define MP4_ATOM_STRING "----:com.apple.iTunes:"
 #define FORMAT_MP4_TAG(s, tag) s.append(MP4_ATOM_STRING).append(tag)
-#define tag_error(t) output_error("Couldn't write to: {}", t.path.string())
 
 using RGTagsArray = std::array<TagLib::String, 7>;
 
@@ -166,99 +165,84 @@ static const std::array<TagLib::String, 2> R128_STRING = {{
 }};
 static_assert((size_t) R128Tag::MAX_VAL == R128_STRING.size());
 
-void tag_track(ScanJob::Track &track, const Config &config)
+bool tag_track(ScanJob::Track &track, const Config &config)
 {
-    std::filesystem::file_time_type mtime;
-    if (config.preserve_mtimes)
-        mtime = std::filesystem::last_write_time(track.path);
-
+    bool ret = false;
     switch (track.type) {
         case FileType::MP2:
         case FileType::MP3:
-            if (!tag_mp3(track, config))
-                tag_error(track);
+            ret = tag_mp3(track, config);
             break;
 
         case FileType::FLAC:
-            if (!tag_flac(track, config))
-                tag_error(track);
+            ret = tag_flac(track, config);
             break;
 
         case FileType::OGG:
             switch (track.codec_id) {
                 case AV_CODEC_ID_OPUS:
-                    if (!tag_ogg<TagLib::Ogg::Opus::File>(track, config))
-                        tag_error(track);
+                    ret = tag_ogg<TagLib::Ogg::Opus::File>(track, config);
                     break;
 
                 case AV_CODEC_ID_VORBIS:
-                    if (!tag_ogg<TagLib::Ogg::Vorbis::File>(track, config))
-                        tag_error(track);
+                    ret = tag_ogg<TagLib::Ogg::Vorbis::File>(track, config);
                     break;
 
                 case AV_CODEC_ID_FLAC:
-                    if (!tag_ogg<TagLib::Ogg::FLAC::File>(track, config))
-                        tag_error(track);
+                    ret = tag_ogg<TagLib::Ogg::FLAC::File>(track, config);
                     break;
 
                 case AV_CODEC_ID_SPEEX:
-                    if (!tag_ogg<TagLib::Ogg::Speex::File>(track, config))
-                        tag_error(track);
+                    ret = tag_ogg<TagLib::Ogg::Speex::File>(track, config);
                     break;
 
                 default:
-                    if (!tag_ogg<TagLib::FileRef>(track, config))
-                        tag_error(track);
+                    ret = tag_ogg<TagLib::FileRef>(track, config);
                     break;
             }
             break;
                 
         case FileType::OPUS:
-            if (!tag_ogg<TagLib::Ogg::Opus::File>(track, config))
-                tag_error(track);
+            ret = tag_ogg<TagLib::Ogg::Opus::File>(track, config);
             break;
 
         case FileType::M4A:
-            if (!tag_mp4(track, config))
-                tag_error(track);
+            ret = tag_mp4(track, config);
             break;
 
         case FileType::WMA:
-            if (!tag_wma(track, config))
-                tag_error(track);
+            ret = tag_wma(track, config);
             break;
 
         case FileType::WAV:
-            if (!tag_riff<TagLib::RIFF::WAV::File>(track, config))
-                tag_error(track);
+            ret = tag_riff<TagLib::RIFF::WAV::File>(track, config);
             break;
 
         case FileType::AIFF:
-            if (!tag_riff<TagLib::RIFF::AIFF::File>(track, config))
-                tag_error(track);
+            ret = tag_riff<TagLib::RIFF::AIFF::File>(track, config);
             break;
 
         case FileType::WAVPACK:
-            if (!tag_apev2<TagLib::WavPack::File>(track, config))
-                tag_error(track);
+            ret = tag_apev2<TagLib::WavPack::File>(track, config);
             break;
             
         case FileType::APE:
         case FileType::TAK:
-            if (!tag_apev2<TagLib::APE::File>(track, config))
-                tag_error(track);
+            ret = tag_apev2<TagLib::APE::File>(track, config);
             break;
 
         case FileType::MPC:
-            if (!tag_apev2<TagLib::MPC::File>(track, config))
-                tag_error(track);
+            ret = tag_apev2<TagLib::MPC::File>(track, config);
             break;
 
         default:
             break;
     }
-    if (config.preserve_mtimes)
-        std::filesystem::last_write_time(track.path, mtime);
+    if (track.mtime)
+        std::filesystem::last_write_time(track.path, *(track.mtime));
+    if (!ret)
+        output_error("Couldn't write tags to: {}", track.path.string());
+    return ret;
 }
 
 bool tag_exists(const ScanJob::Track &track)
@@ -446,24 +430,26 @@ static bool tag_flac(ScanJob::Track &track, const Config &config)
 
 template<typename T>
 static bool tag_ogg(ScanJob::Track &track, const Config &config) {
-    T file(track.path.string().c_str());
-    TagLib::Ogg::XiphComment *tag = nullptr;
-    if constexpr(std::is_same_v<T, TagLib::FileRef>)
-        tag = dynamic_cast<TagLib::Ogg::XiphComment*>(file.tag());
-    else
-        tag = file.tag();
-    if (!tag)
-        return false;
-    tag_clear<T>(tag);
-    if (config.tag_mode == 'i' && (!std::is_same_v<T, TagLib::Ogg::Opus::File> || 
-    (config.opus_mode != 't' && config.opus_mode != 'a')))
-        tag_write<T>(tag, track.result, config);
+    {
+        T file(track.path.string().c_str());
+        TagLib::Ogg::XiphComment* tag = nullptr;
+        if constexpr (std::is_same_v<T, TagLib::FileRef>)
+            tag = dynamic_cast<TagLib::Ogg::XiphComment*>(file.tag());
+        else
+            tag = file.tag();
+        if (!tag)
+            return false;
+        tag_clear<T>(tag);
+        if (config.tag_mode == 'i' && (!std::is_same_v<T, TagLib::Ogg::Opus::File> ||
+            (config.opus_mode != 't' && config.opus_mode != 'a')))
+            tag_write<T>(tag, track.result, config);
 
-    bool ret = file.save();
-    if (!std::is_same_v<T, TagLib::Ogg::Opus::File> || config.tag_mode == 's' || 
-    !(config.opus_mode == 't' || config.opus_mode == 'a') || !ret)
-        return ret;
+        bool ret = file.save();
+        if (!std::is_same_v<T, TagLib::Ogg::Opus::File> || config.tag_mode == 's' ||
+            !(config.opus_mode == 't' || config.opus_mode == 'a') || !ret)
+            return ret;
 
+    }
     int16_t gain = config.opus_mode == 'a' && config.do_album ? 
     GAIN_TO_Q78(track.result.album_gain) : GAIN_TO_Q78(track.result.track_gain);
     return set_opus_header_gain(track.path.string().c_str(), gain);
@@ -636,12 +622,12 @@ static void tag_write(TagLib::Ogg::XiphComment *tag, const ScanResult &result, c
     // Opus RFC 7845 tag
     if (std::is_same_v<T, TagLib::Ogg::Opus::File> && (config.opus_mode == 'r' || config.opus_mode == 's')) {
         tag->addField(R128_STRING[static_cast<int>(R128Tag::TRACK_GAIN)], 
-            format("{}", GAIN_TO_Q78(result.track_gain))
+            rsgain::format("{}", GAIN_TO_Q78(result.track_gain))
         );
 
         if (config.do_album) {
             tag->addField(R128_STRING[static_cast<int>(R128Tag::ALBUM_GAIN)], 
-                format("{}", GAIN_TO_Q78(result.album_gain))
+                rsgain::format("{}", GAIN_TO_Q78(result.album_gain))
             );
         }
     }
@@ -722,13 +708,16 @@ static void tag_write(TagLib::ASF::Tag *tag, const ScanResult &result, const Con
 }
 
 static_assert(-1 == ~0); // 2's complement for signed integers
-bool set_opus_header_gain(const char *path, int16_t gain)
-{   
+bool set_opus_header_gain(const char* path, int16_t gain)
+{
     uint32_t crc;
-    if constexpr(std::endian::native == std::endian::big)
+    if constexpr (std::endian::native == std::endian::big)
         gain = static_cast<int16_t>((gain << 8) & 0xff00) | ((gain >> 8) & 0x00ff);
-    
+
     std::unique_ptr<std::FILE, int (*)(FILE*)> file(fopen(path, "rb+"), fclose);
+    if (!file)
+        return false;
+
     char buffer[8];
     size_t page_size = 0;
     size_t opus_header_size = 0;
